#ifndef PW_CORE_MESH_HPP
#define PW_CORE_MESH_HPP

#include <pw/core/globals.hpp>
#include <pw/core/vector.hpp>

namespace pw {

class mesh {
public:

	typedef std::vector<int32_t> indexarray_t;
	typedef std::vector<vector3> vertex3array_t;
	typedef std::vector<vector2> vertex2array_t;

	enum topology_type {
		triangles,
		triangle_strip,
		triangle_fan,
		quads,
		lines,
		line_strip,
		points
	};

	void set_indices(const indexarray_t& v) { _indices = v; }
	void set_vertices(const vertex3array_t& v) { _vertices = v; }

	const indexarray_t& indices() const { return _indices; }
	const vertex3array_t& vertices() const { return _vertices; }

	void reset();

protected:

	indexarray_t _indices; //!< indices according to topology type
	vertex3array_t _vertices; //!< geometry data
	vertex3array_t _normals; //!< normal data
	vertex3array_t _colors; //!< color data

	std::vector<vertex2array_t> _uvs;			//!< storing multiple UV sets

	// TODO add weights, tangents etc. pp.
};

}

#endif

